@@ -2,7 +2,7 @@
 from typing import Optional
 from uuid import UUID
 
-from httpx import StatusCode
+import httpx
 
 from botx.clients.methods.base import AuthorizedBotXMethod
 from botx.clients.methods.errors import bot_is_not_admin, chat_not_found
@@ -15,8 +15,8 @@ class StealthSet(AuthorizedBotXMethod[bool]):
     __method__ = "POST"
     __returning__ = bool
     __errors_handlers__ = {
-        StatusCode.FORBIDDEN: bot_is_not_admin.handle_error,
-        StatusCode.NOT_FOUND: chat_not_found.handle_error,
+        httpx.codes.FORBIDDEN: bot_is_not_admin.handle_error,
+        httpx.codes.NOT_FOUND: chat_not_found.handle_error,
     }
 
     #: ID of chat where stealth should be enabled.
